@@ -35,6 +35,9 @@ def main():
     # Set directory containing BEAGLE results files
     BeagleDirectories.results_dir = args.results_dir
 
+    # Configure matplotlib
+    configure_matplotlib()
+
     # Read parameter file
     config = ConfigParser.SafeConfigParser()
 
@@ -112,7 +115,7 @@ def main():
     params_file = os.path.join(BeagleDirectories.results_dir, args.json_file_triangle)
 
     # Compute the summary catalogue
-    summary_catalogue = BeagleSummaryCatalogue(credible_intervals=args.credible_interval)
+    summary_catalogue = BeagleSummaryCatalogue(credible_intervals=args.credible_interval, n_proc=args.n_proc)
     if args.compute_summary:
         if not summary_catalogue.exists():
             summary_catalogue.compute(file_list)
@@ -146,7 +149,8 @@ def main():
                 x_log=args.plot_log_wl, 
                 log_flux=args.plot_log_flux,
                 plot_single_solution=args.plot_single_solution,
-                plot_full_SED=args.plot_full_SED)
+                plot_full_SED=args.plot_full_SED,
+                plot_filter_labels=args.plot_filter_labels)
 
         # We can load a set of photometric filters
         try:
@@ -154,7 +158,10 @@ def main():
             filters_throughputs = None
         except:
             filters_file = os.path.expandvars(config.get('main', 'FILTERS CONFIGURATION'))
-            filters_throughputs = os.path.expandvars(config.get('main', 'FILTERS THROUGHPUTS'))
+            try:
+                filters_throughputs = os.path.expandvars(config.get('main', 'FILTERS THROUGHPUTS'))
+            except:
+                filters_throughputs = None
 
         my_photometry.filters.load(filters_file, 
                 filters_folder=args.filters_folder, 
@@ -214,12 +221,12 @@ def main():
                     break
 
     # Create "pool" of processes
-    if args.np > 1:
-        pool = ProcessingPool(nodes=args.np)
+    if args.n_proc > 1:
+        pool = ProcessingPool(nodes=args.n_proc)
 
     # Plot the marginal SED
     if args.plot_marginal:
-        if args.np > 1:
+        if args.n_proc > 1:
             if has_spectra:
                 pool.map(my_spectrum.plot_marginal, IDs, file_names)
 
@@ -241,7 +248,7 @@ def main():
                 mock_catalogue=mock_catalogue,
                 plot_single_solution=args.plot_single_solution)
 
-        if args.np > 1:
+        if args.n_proc > 1:
             pool.map(my_PDF.plot_triangle, IDs)
         else:
             for ID in IDs:
